@@ -298,7 +298,7 @@ class EnhancedAdminMixin(admin.ModelAdmin,
             extra_context.update(
                 hide_save_buttons=self.hide_save_buttons(request, object_id)
             )
-        if request.method == 'POST' and extra_context['hide_save_buttons']:
+        if request.method == 'POST' and self.hide_save_buttons(request, object_id):
             raise PermissionDenied()
         response = super().change_view(request, object_id, form_url, extra_context)
         if request.method == 'POST':
