@@ -21,4 +21,4 @@ def ajax_callback_handler(request, name, pk):
 
 @csrf_exempt
 def is_user_authenticated(request):
-    return JsonResponse(request.user.is_authenticated)
+    return JsonResponse(request.user.is_authenticated, safe=False)
